@@ -8,7 +8,7 @@ package App::MatrixTool;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Getopt::Long qw( GetOptionsFromArray );
 use Future;
@@ -20,6 +20,8 @@ use Scalar::Util qw( blessed );
 use Socket qw( getnameinfo AF_INET AF_INET6 AF_UNSPEC NI_NUMERICHOST NI_NUMERICSERV );
 use Struct::Dumb qw( readonly_struct );
 
+use Protocol::Matrix::HTTP::Federation;
+
 my $opt_parser = Getopt::Long::Parser->new(
    config => [qw( require_order )],
 );
@@ -220,6 +222,13 @@ sub error
 
 ## Command support
 
+sub federation
+{
+   my $self = shift;
+
+   return $self->{federation} ||= Protocol::Matrix::HTTP::Federation->new;
+}
+
 sub http_client
 {
    my $self = shift;
@@ -307,7 +316,7 @@ EOF
 
    my @commands = $self->commands;
 
-   my $namelen = max map { length $_->[0] } @commands;
+   my $namelen = max map { length $_->name } @commands;
 
    $self->output( "Commands:\n" .
       join "\n", map { sprintf "  %-*s    %s", $namelen, $_->name, $_->description } @commands
