@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use base qw( App::MatrixTool );
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use MIME::Base64 qw( decode_base64 );
 use Protocol::Matrix qw( verify_json_signature );
@@ -39,9 +39,10 @@ sub get_key_v1
    my $server_cert;
 
    $self->http_client->request_json(
-      method => "GET",
-      server => $server_name,
-      path   => "/_matrix/key/v1",
+      server  => $server_name,
+      request => $self->federation->make_key_v1_request(
+         server_name => $server_name,
+      ),
 
       on_ready => sub {
          my ( $conn ) = @_;
@@ -90,9 +91,11 @@ sub get_key_v2
    my $server_cert;
 
    $self->http_client->request_json(
-      method => "GET",
-      server => $server_name,
-      path   => "/_matrix/key/v2/server/*",
+      server  => $server_name,
+      request => $self->federation->make_key_v2_server_request(
+         server_name => $server_name,
+         key_id      => "*",
+      ),
 
       on_ready => sub {
          my ( $conn ) = @_;
