@@ -8,7 +8,7 @@ package App::MatrixTool::HTTPClient;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Future 0.33; # ->catch
 use Future::Utils qw( repeat_until_success );
@@ -144,7 +144,7 @@ sub request
    my %params = @_;
 
    my $ua  = $self->ua;
-   my $req = HTTP::Request->new( $params{method} => $params{path},
+   my $req = $params{request} // HTTP::Request->new( $params{method} => $params{path},
       [ Host => $params{server} ],
    );
    $req->protocol( "HTTP/1.1" );
