@@ -2,6 +2,7 @@
 
 use strict;
 use warnings;
+use 5.014;  # s///r
 
 use blib;
 
@@ -28,10 +29,10 @@ print "\n";
 foreach my $cmd ( $helpcmd->commands ) {
    my $cmdname = $cmd->name;
 
-   print <<"EOF";
-=head2 $cmdname
+   print <<"EOF" =~ s/^ {6}//mgr;
+      =head2 $cmdname
 
-${\ $cmd->description }
+      ${\ $cmd->description }
 EOF
 
    my @argspecs = @{ $cmd->argspecs };
@@ -43,10 +44,10 @@ EOF
 
    next unless my $optspecs = $cmd->optspecs;
 
-   print <<"EOF";
-Options:
+   print <<"EOF" =~ s/^ {6}//mgr;
+      Options:
 
-=over 4
+      =over 4
 
 EOF
 
@@ -54,16 +55,16 @@ EOF
       my $name = "--".$optspec->print_name;
       $name .= " (-".$optspec->shortname.")" if defined $optspec->shortname;
 
-      print <<"EOF";
-=item * $name
+      print <<"EOF" =~ s/^ {9}//mgr;
+         =item * $name
 
-${\ $optspec->description }
+         ${\ $optspec->description }
 
 EOF
    }
 
-   print <<"EOF";
-=back
+   print <<"EOF" =~ s/^ {6}//mgr;
+      =back
 
 EOF
 }
